Installation
############

JaxLayerLumos can be easily installed by the following command using the `PyPI repository <https://pypi.org/project/jaxlayerlumos/>`_.

.. code-block:: bash

    pip install jaxlayerlumos

Alternatively, JaxLayerLumos can be installed from source.

.. code-block:: bash

    pip install .

In addition, we support three installation modes, ``dev``, ``benchmarking``, and ``examples``, where ``dev`` is defined for installing the packages required for development and software testing, ``benchmarking`` is for installing the packages required for benchmarking against differnt TMM software programs, and ``examples`` is needed for running the examples included in the ``examples`` directory. One of these modes can be used by commanding ``pip install .[dev]``, ``pip install .[benchmarking]``, or ``pip install .[examples]``.
